# coding: utf-8

# flake8: noqa

"""
    Gopad OpenAPI

    API definition for Gopad, Etherpad for markdown with go

    The version of the OpenAPI document: 1.0.0-alpha1
    Contact: gopad@webhippie.de
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.6.0"

# import apis into sdk package
from gopad.api.auth_api import AuthApi
from gopad.api.group_api import GroupApi
from gopad.api.profile_api import ProfileApi
from gopad.api.user_api import UserApi

# import ApiClient
from gopad.api_response import ApiResponse
from gopad.api_client import ApiClient
from gopad.configuration import Configuration
from gopad.exceptions import OpenApiException
from gopad.exceptions import ApiTypeError
from gopad.exceptions import ApiValueError
from gopad.exceptions import ApiKeyError
from gopad.exceptions import ApiAttributeError
from gopad.exceptions import ApiException

# import models into sdk package
from gopad.models.auth_token import AuthToken
from gopad.models.auth_verify import AuthVerify
from gopad.models.create_group_request import CreateGroupRequest
from gopad.models.create_user_request import CreateUserRequest
from gopad.models.delete_group_from_user_request import DeleteGroupFromUserRequest
from gopad.models.delete_user_from_group_request import DeleteUserFromGroupRequest
from gopad.models.group import Group
from gopad.models.list_group_users200_response import ListGroupUsers200Response
from gopad.models.list_groups200_response import ListGroups200Response
from gopad.models.list_providers200_response import ListProviders200Response
from gopad.models.list_user_groups200_response import ListUserGroups200Response
from gopad.models.list_users200_response import ListUsers200Response
from gopad.models.login_auth_request import LoginAuthRequest
from gopad.models.notification import Notification
from gopad.models.permit_group_user_request import PermitGroupUserRequest
from gopad.models.permit_user_group_request import PermitUserGroupRequest
from gopad.models.profile import Profile
from gopad.models.provider import Provider
from gopad.models.update_profile_request import UpdateProfileRequest
from gopad.models.update_user_request import UpdateUserRequest
from gopad.models.user import User
from gopad.models.user_auth import UserAuth
from gopad.models.user_group import UserGroup
from gopad.models.validation import Validation
